{% load i18n %}
<h5>{% trans "Summary" %}</h5>
<ul class="list-group list-group-flush">
    {% for model_name, object_count in model_count %}
    <li class="list-group-item">{{ model_name|capfirst }}: {{ object_count }}</li>
    {% endfor %}
</ul>
