{% extends "admin/base.html" %}

{% block title %}{{ title }} | {{ site_title|default:_('Django site admin') }}{% endblock %}

{% block branding %}
<a class="app-header__logo" href="{% url 'admin:index' %}">{{ site_header|default:_('Django administration') }}</a>
{% endblock %}

{% block nav-global %}{% endblock %}
