{% load i18n admin_urls %}
<div class="tile submit-row">
    {% if show_delete_link %}
    {% url opts|admin_urlname:'delete' original.pk|admin_urlquote as delete_url %}
    <a href="{% add_preserved_filters delete_url %}" class="btn btn-danger btn-sm pull-left"><i class="fa fa-times" style="margin-top:-3px"></i>{% trans "Delete" %}</a>
{% endif %}
{% if show_save %}<button type="submit" value="{% trans 'Save' %}" class="default btn btn-primary btn-sm" name="_save" ><i class="fa fa-floppy-o" style="margin-top:-3px"></i>{% trans 'Save' %}</button>{% endif %}

    {% if show_save_as_new %}<button type="submit" value="{% trans 'Save as new' %}" name="_saveasnew" class="default btn btn-secondary btn-sm">{% trans 'Save as new' %}</button>{% endif %}
    {% if show_save_and_add_another %}<button type="submit" value="{% trans 'Save and add another' %}" name="_addanother" class="default btn btn-secondary btn-sm">{% trans 'Save and add another' %}</button>{% endif %}
    {% if show_save_and_continue %}<button type="submit" value="{% trans 'Save and continue editing' %}" name="_continue" class="default btn btn-secondary btn-sm">{% trans 'Save and continue editing' %}</button>{% endif %}
</div>
